Musik und Filme im Shop für CDs, DVDs und Blu-rays – jpc.de
Description: Im Shop finden Sie über 4 Mio. CDs, Blu-rays, DVDs und Bücher. Portofreier Versand für alle Bestellungen ab 20 €. Jetzt stöbern!

Anmelden Konto anlegen

Bis Sonntag alle Bestellungen portofrei

Pop/Rock
ZZ Top: Live At Montreux 2013

Pop/Rock
Sing meinen Song: Weihnachtskonzert Vol. 2

Pop/Rock
Unheilig: MTV Unplugged »Unter Dampf – Ohne Strom«

1. Bis Sonntag alle Bestellungen portofrei

2. ZZ Top: Live At Montreux 2013

3. Sing meinen Song: Weihnachtskonzert Vol. 2

4. Unheilig: MTV Unplugged »Unter Dampf – Ohne Strom«

## Diese Woche aktuell

- Pop/Rock
- Jazz
- Klassik
- Vinyl
- Filme
- Bücher

Aktuelles aus Pop und Rock in dieser Woche

Unheilig
MTV Unplugged »Unter Dampf – Ohne Strom«
EUR 18,99**
CD
EUR 17,99*
Sing meinen Song: Das Weihnachtskonzert Vol. 2
CD
EUR 16,99*
Chris Rea
La Passione
2 CDs, 2 DVDs
EUR 44,95*
Charles Aznavour
Aznavour Live - Palais Des Sports 2015
CD
EUR 17,99*
Bratislava Symphony Orchestra
35 Jahre Böhse Onkelz - Symphonien und Sonaten
2 CDs
EUR 16,99*
Dieter Thomas Kuhn
Im Auftrag der Liebe - Live
2 CDs
EUR 18,99*
Andreas Gabalier
Mountain Man (Limited Tour Edition)
2 CDs
EUR 19,99*
The Dome Vol. 76
EUR 21,99**
2 CDs
EUR 19,99*
Die ultimative Chartshow - Hits 2015
EUR 20,99**
2 CDs
EUR 19,99*
Unterhaltungsmusik / Schlager / Instrumental
Apres Ski Hits 2016 - XXL Fan Edition
3 CDs
EUR 24,99*
Das komplette Angebot Pop/Rock

## jpc-Charts

- Pop/Rock
- Jazz
- Klassik
- Filme

1. 1
   Adele 25
2. 2
   Helene Fischer Weihnachten
3. 3
   Coldplay A Head Full Of Dreams
4. 4
   David Bowie Blackstar (180g) (Limited Edition) (Clear Vinyl) - exklusiv bei jpc!
5. 5
   Adele 25
6. 6
   Pink Floyd The Division Bell (2011 remastered) (Limited Edition) (CD + 2 LP + 1 Blu-ray + 2 7"es + 12" + Kunstdruck)
7. 7
   Bravo The Hits 2015
8. 8
   Coldplay A Head Full Of Dreams (180g) (Limited Edition) (Colored Vinyl)
9. 9
   Die ultimative Chartshow - Hits 2015
10. 10
    Bruce Springsteen The Ties That Bind: The River Collection (Boxset)
11. Die kompletten Pop/Rock-Charts

## Aktuell in der Shop-Redaktion besprochen

### Deutschland 83

Maulwurfsjagd in der heißesten Phase des Kalten Krieges Die TV-Serie »Deutschland 83« zeigt 2015 – 32 ...

### Unantastbar: Hand aufs Herz

Unantastbar legen die Hand aufs Herz »Hand aufs Herz« heißt das neue Album von Unantastbar. Nachdem die ...

### Dota: Keine Gefahr – exklusive jpc-Edition mit ...

»Keine Gefahr« – oder doch? Einst verdiente sich die »Kleingeldprinzessin« auf Reisen ihr Geld als ...

### Star Wars: The Force Awakens

Möge die Musik mit Dir sein – der Soundtrack zum neuen Star-Wars-Film »Star Wars« ist Kult. Bereits 1977 ...

### Baroness: Purple

Das violette Album von Baroness In ihrer mittlerweile zehnjährigen Karriere haben Baroness gleich mehrere ...

## Der Shop auf einen Blick

1. ### Pop/Rock

   - Charts
   - Neuheiten
   - Sonderangebote
   Beliebte Genres
   - Blues
   - Independent
   - Metal
   - Schlager
   - Weltmusik
   Audiophile Formate
   - Vinyl (200 g)
   - SHM-CD
   - Blu-ray Disc

2. ### Jazz

   - Jazz-Charts
   - Jazz-Neuheiten
   - Jazz-Angebote
   Beliebte Genres
   - Big Band/Swing
   - Dixieland/New Orleans
   - Modern Jazz
   - Piano Jazz
   - Vocal Jazz
   Audiophile Formate
   - SACD
   - Vinyl (200 g)
   - Blu-ray Disc

3. ### Klassik

   - Klassik-Charts
   - Klassik-Neuheiten
   - Klassik-Angebote
   Beliebte Genres
   - Orchesterwerke
   - Klavier-, Cembalo- und Orgelkonzerte
   - Streichquartette
   - Oper, Oratorium, Singspiel
   - Geistliche Musik
   Audiophile Formate
   - SACD
   - Blu-ray Audio
   - XRCD

4. ### Filme

   - Film-Charts
   - Film-Neuheiten
   - Film-Sonderangebote
   Beliebte Genres
   - Action
   - Erotik
   - Komödien
   - TV-Serien aus Deutschland
   Filme in High Definition
   - Blu-ray Disc
   - 3D Blu-ray
   - 4K Mastered

5. ### Bücher

   - Buch-Bestseller
   - Buch-Neuheiten
   Top-Kategorien
   - Belletristik
   - Sachbücher & Ratgeber
   - Musikbücher
   - Filmbücher
   - English Books
   - Taschenbücher
   - Hörbücher
   - eBooks

6. ### Labels

   Pop/Rock
   - BELL Musik
   - Bear Family Records
   - Rhino Entertainment
   - Ariola Schlagershop
   Jazz
   - ACT Company
   - Blue Note Records
   - ECM Records
   Klassik
   - Deutsche Grammophon
   - Naxos
   - cpo

## Specials

1. ### Neue Sonderangebote

   - Pop/Rock
   - Jazz
   - Klassik
   - Filme
   In der Vorschau
   - David Bowie: Blackstar
   - Niedeckens BAP: Lebenslänglich
   - Unheilig: MTV Unplugged

2. ### Bündelangebote mit Preisvorteil

   - 3 CDs von Warner Music für 18 Euro
   - 3 CDs von cpo nur 18 Euro
   - 3 Filme auf DVD für 15 Euro
   - 3 Filme auf Blu-ray Disc für 18 Euro

3. ### Exklusiv für jpc-Kunden

   - Vom Künstler signierte Artikel
   Aus der Technikabteilung
   - Plattenspieler aus dem Hause Rega

4. ### Für Sammler

   - Papersleeves
   - Colored Vinyl
   - Clear Vinyl
   - Picture Discs
   - Shaped Vinyl
   Fan-Artikel
   - T-Shirts und Merchandise

5. ### Aus unserer Buchabteilung

   - Buchhighlights der nächsten Monate – Jetzt vorbestellen
   - Schulbücher bestellen

6. ### courier 1/2016

© jpc-schallplatten Versandhandelsgesellschaft mbH